#ifndef VIEWER_H
#define VIEWER_H

#include <aabbox.h>
#include <QGLViewer/qglviewer.h>
#include <deque>

class Viewer : public QGLViewer
{
public:
  Viewer(QWidget* parent=NULL);
  void loadModel(const char* fileName);
  void computeLOD(float percentage);
  int  idCellContaining(const qglviewer::Vec& v) const;
protected:
  virtual void draw();
  virtual void keyPressEvent(QKeyEvent* e);
private:
  typedef std::deque<qglviewer::Vec> Cell;
  // Data for the model
  std::deque<qglviewer::Vec> vertices;
  std::deque<qglviewer::Vec> faceNormals;
  std::deque<int>            faces;
  AABBox                     bbox;
  // Data for the grid
  float                      size;
  unsigned int               nbI;
  unsigned int               nbJ;
  unsigned int               nbK;
  Cell*                      cells;
  // Data for the LOD
  std::deque<qglviewer::Vec> lodVertices;
  std::deque<int>            lodTriangles;
  std::deque<qglviewer::Vec> lodTriangleNormals;
  // Data for display options
  bool wireFrame;
  bool drawBBox;
  bool drawGrid;
  bool drawLOD;
};

#endif // VIEWER_H
